@@ -1,13 +1,13 @@
 #!/bin/sh
 echo 'name: MonadCatchIO-mtl
-version: 0.3.0.2
-id: MonadCatchIO-mtl-0.3.0.2-d37299717086611240bcc2c804af186d
+version: 0.3.0.4
+id: MonadCatchIO-mtl-0.3.0.4-71e86801e5931fd974633b3c7e6e1486
 
 license: BSD3
 copyright:
 maintainer: jcpetruzza@gmail.com
 stability:
-homepage: http://code.haskell.org/~jcpetruzza/MonadCatchIO-mtl
+homepage: http://darcsden.com/jcpetruzza/MonadCatchIO-mtl
 package-url:
 description: Provides a monad-transformer version of the @Control.Exception.catch@
              function. For this, it defines the @MonadCatchIO@ class, a subset of
@@ -19,21 +19,21 @@ pkgpath: devel/hs-MonadCatchIO-mtl
 exposed: True
 exposed-modules: Control.Monad.CatchIO
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.2
-library-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.2
-hs-libraries: HSMonadCatchIO-mtl-0.3.0.2
+import-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.4
+library-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.4
+hs-libraries: HSMonadCatchIO-mtl-0.3.0.4
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
+depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
          extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
-         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
+         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.2/html/MonadCatchIO-mtl.haddock
-haddock-html: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.2/html
+haddock-interfaces: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.4/html/MonadCatchIO-mtl.haddock
+haddock-html: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.4/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
